pub enum CallableDidNotExecuteError {
PipeCreationFailed(Error),
ChildPipeCloseFailed(Option<Error>),
ForkFailed(Error),
}Expand description
An error indicating something went wrong before the user-supplied callable was executed
It is harmless to retry the callable.
Variants
PipeCreationFailed(Error)
A system error occurred while creating the pipe used to communicate with the child process
ChildPipeCloseFailed(Option<Error>)
A system error occurred while closing the child process’s copy of the pipe’s read end
ForkFailed(Error)
A system error occurred while forking the child process which is used to execute user-supplied callable