pub enum CallableStatusUnknownError {
ParentPipeCloseFailed(Error),
WaitFailed(Error),
ParentPipeReadFailed(Error),
CallableProcessDiedDuringExecution,
UnexpectedChildExitStatus(i32),
ChildProcessKilledBySignal(i32),
UnexpectedWaitpidReturnValue(i32),
}Expand description
An error indicating that something went wrong in a way where it is difficult
or impossible to determine whether the user-supplied callable was executed
¯\_(ツ)_/¯
You should only retry the callable if it is idempotent.
Variants
ParentPipeCloseFailed(Error)
A system error occurred while closing the parent’s copy of the pipe’s write end
WaitFailed(Error)
A system error occurred while waiting for the child process to exit
ParentPipeReadFailed(Error)
A system error occurred while reading the child’s result from the pipe
CallableProcessDiedDuringExecution
The callable process died while executing the user-supplied callable
UnexpectedChildExitStatus(i32)
The child process responsible for executing the user-supplied callable exited with an unexpected status
Note this does not represent some sort of exit code or return value indicating the success or failure of the user-supplied callable itself.
ChildProcessKilledBySignal(i32)
The child process responsible for executing the user-supplied callable was killed by a signal
UnexpectedWaitpidReturnValue(i32)
Waitpid returned an unexpected value