pub enum MemIsolateError {
CallableDidNotExecute(CallableDidNotExecuteError),
CallableExecuted(CallableExecutedError),
CallableStatusUnknown(CallableStatusUnknownError),
}Expand description
MemIsolateError is the primary error type returned by the crate. The
goal is to give the caller context about what happened to their callable if
something went wrong.
For basic usage, and an introduction of how you should think about error
handling with this crate, see
examples/error-handling-basic.rs
For an exhaustive look of all possible error variants, see examples/error-handling-complete.rs
Variants
CallableDidNotExecute(CallableDidNotExecuteError)
Indicates something went wrong before the callable was executed. Because the callable never executed, it should be safe to naively retry the callable with or without mem-isolate, even if the function is not idempotent.
CallableExecuted(CallableExecutedError)
Indicates something went wrong after the callable was executed. Do not retry execution of the callable unless it is idempotent.
CallableStatusUnknown(CallableStatusUnknownError)
Indicates something went wrong, but it is unknown whether the callable was executed. You should retry the callable only if it is idempotent.